@@ -9,7 +9,7 @@
  *                         data_database, data_database_reader, ctrl_classifier_controller
  */
 
-#include <test_suite.h>
+#include "test_suite.h"
 
 test_suite_t ctrl_classifier_controller_test_get_list(void);
 
@@ -17,7 +17,7 @@ test_suite_t ctrl_classifier_controller_test_get_list(void);
 
 
 /*
- * Copyright 2016-2020 Andreas Warnke
+ * Copyright 2016-2021 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
