@@ -7,7 +7,6 @@
 #include "storage/data_database_reader.h"
 #include "trace.h"
 #include "test_assert.h"
-#include <stdio.h>
 
 static void set_up(void);
 static void tear_down(void);
@@ -27,11 +26,6 @@ static void repair_ill_feature_relationship(void);
  */
 static data_database_t database;
 
-/*!
- *  \brief database filename on which the tests are performed and which is automatically deleted when finished
- */
-static const char* DATABASE_FILENAME = "unittest_crystal_facet_uml_default.cfu1";
-
 /*!
  *  \brief database reader to access the database
  */
@@ -77,7 +71,7 @@ test_suite_t ctrl_consistency_checker_test_get_list(void)
 static void set_up(void)
 {
     data_database_init( &database );
-    data_database_open( &database, DATABASE_FILENAME );
+    data_database_open_in_memory( &database );
 
     data_database_reader_init( &db_reader, &database );
     data_database_writer_init( &db_writer, &db_reader, &database );
@@ -146,7 +140,6 @@ static void set_up(void)
 
 static void tear_down(void)
 {
-    int err;
     ctrl_controller_destroy( &controller );
 
     data_database_writer_destroy( &db_writer );
@@ -154,8 +147,6 @@ static void tear_down(void)
 
     data_database_close( &database );
     data_database_destroy( &database );
-    err = remove( DATABASE_FILENAME );
-    TEST_ENVIRONMENT_ASSERT ( 0 == err );
 }
 
 static void diagram_two_roots_consistency(void)
@@ -1079,7 +1070,7 @@ static void repair_ill_feature_relationship(void)
 
 
 /*
- * Copyright 2016-2020 Andreas Warnke
+ * Copyright 2016-2021 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
