@@ -9,7 +9,7 @@
  *  focussing on opening, switching and closing files
  */
 
-#include <test_suite.h>
+#include "test_suite.h"
 
 test_suite_t ctrl_controller_test_get_list(void);
 
@@ -17,7 +17,7 @@ test_suite_t ctrl_controller_test_get_list(void);
 
 
 /*
- * Copyright 2018-2020 Andreas Warnke
+ * Copyright 2018-2021 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
