@@ -196,7 +196,7 @@ static void create_diagramelements_and_delete(void)
         TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, data_err );
         ctrl_err = ctrl_classifier_controller_create_classifier ( classifier_ctrl,
                                                                   &new_classifier,
-                                                                  false,  /* add_to_latest_undo_set */
+                                                                  CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                                   &classifier_id
                                                                 );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -215,7 +215,7 @@ static void create_diagramelements_and_delete(void)
                                      );
         ctrl_err = ctrl_diagram_controller_create_diagramelement ( diagram_ctrl,
                                                                    &new_diagele,
-                                                                   true,  /* add_to_latest_undo_set */
+                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &diag_element_id
                                                                  );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
