@@ -2,6 +2,7 @@
 
 #include "ctrl_diagram_policy_enforcer_test.h"
 #include "ctrl_controller.h"
+#include "test_env/test_env_setup_data.h"
 #include "storage/data_database.h"
 #include "storage/data_database_writer.h"
 #include "storage/data_database_reader.h"
@@ -12,6 +13,7 @@ static void set_up(void);
 static void tear_down(void);
 static void diagram_to_lifeline_consistency(void);
 static void diagramelement_to_lifeline_consistency(void);
+static void no_hidden_relationships(void);
 
 /*!
  *  \brief database instance on which the tests are performed
@@ -39,6 +41,7 @@ test_suite_t ctrl_diagram_policy_enforcer_test_get_list(void)
     test_suite_init( &result, "ctrl_diagram_policy_enforcer_test", &set_up, &tear_down );
     test_suite_add_test_case( &result, "diagram_to_lifeline_consistency", &diagram_to_lifeline_consistency );
     test_suite_add_test_case( &result, "diagramelement_to_lifeline_consistency", &diagramelement_to_lifeline_consistency );
+    test_suite_add_test_case( &result, "no_hidden_relationships", &no_hidden_relationships );
     return result;
 }
 
@@ -91,7 +94,7 @@ static void diagram_to_lifeline_consistency(void)
         root_diag_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagram ( diagram_ctrl,
                                                             &root_diagram,
-                                                            false, /* add_to_latest_undo_set */
+                                                            CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                             &root_diag_id
                                                           );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -116,7 +119,7 @@ static void diagram_to_lifeline_consistency(void)
         child_diag_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagram ( diagram_ctrl,
                                                             &child_diagram,
-                                                            true, /* add_to_latest_undo_set */
+                                                            CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                             &child_diag_id
                                                           );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -142,7 +145,7 @@ static void diagram_to_lifeline_consistency(void)
         classifier_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_classifier_controller_create_classifier ( classifier_ctrl,
                                                                   &new_classifier,
-                                                                  true,  /* add_to_latest_undo_set */
+                                                                  CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                   &classifier_id
                                                                 );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -164,7 +167,7 @@ static void diagram_to_lifeline_consistency(void)
         root_diag_element_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagramelement ( diagram_ctrl,
                                                                    &new_diagele,
-                                                                   true,  /* add_to_latest_undo_set */
+                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &root_diag_element_id
                                                                  );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -186,7 +189,7 @@ static void diagram_to_lifeline_consistency(void)
         child_diag_element_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagramelement ( diagram_ctrl,
                                                                    &new_diagele2,
-                                                                   true,  /* add_to_latest_undo_set */
+                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &child_diag_element_id
                                                                  );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -243,13 +246,13 @@ static void diagram_to_lifeline_consistency(void)
     {
         ctrl_err = ctrl_diagram_controller_delete_diagramelement ( diagram_ctrl,
                                                                    child_diag_element_id,
-                                                                   false /* add_to_latest_undo_set */
+                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW
                                                                  );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
 
         ctrl_err = ctrl_diagram_controller_delete_diagram ( diagram_ctrl,
                                                             child_diag_id,
-                                                            true /* add_to_latest_undo_set */
+                                                            CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND
                                                           );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
     }
@@ -294,7 +297,7 @@ static void diagramelement_to_lifeline_consistency(void)
         root_diag_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagram ( diagram_ctrl,
                                                             &root_diagram,
-                                                            false, /* add_to_latest_undo_set */
+                                                            CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                             &root_diag_id
         );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -320,7 +323,7 @@ static void diagramelement_to_lifeline_consistency(void)
         classifier_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_classifier_controller_create_classifier ( classifier_ctrl,
                                                                   &new_classifier,
-                                                                  false,  /* add_to_latest_undo_set */
+                                                                  CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                                   &classifier_id
         );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -342,7 +345,7 @@ static void diagramelement_to_lifeline_consistency(void)
         first_diag_element_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagramelement ( diagram_ctrl,
                                                                    &new_diagele,
-                                                                   true,  /* add_to_latest_undo_set */
+                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &first_diag_element_id
                                                                  );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -364,7 +367,7 @@ static void diagramelement_to_lifeline_consistency(void)
         second_diag_element_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagramelement ( diagram_ctrl,
                                                                    &new_diagele2,
-                                                                   true,  /* add_to_latest_undo_set */
+                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &second_diag_element_id
                                                                  );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
@@ -393,7 +396,7 @@ static void diagramelement_to_lifeline_consistency(void)
     {
         ctrl_err = ctrl_diagram_controller_delete_diagramelement ( diagram_ctrl,
                                                                    first_diag_element_id,
-                                                                   false /* add_to_latest_undo_set */
+                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW
                                                                  );
         TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, ctrl_err );
     }
@@ -423,6 +426,58 @@ static void diagramelement_to_lifeline_consistency(void)
     }
 }
 
+static void no_hidden_relationships(void)
+{
+    ctrl_diagram_controller_t *diagram_ctrl;
+    diagram_ctrl = ctrl_controller_get_diagram_control_ptr( &controller );
+    
+    /* create 2 diagrams */
+    const data_row_id_t root_diagram = test_env_setup_data_create_diagram( DATA_ROW_ID_VOID, "root diag", &controller );
+    const data_row_id_t local_diagram = test_env_setup_data_create_diagram( root_diagram, "local diag", &controller );
+    
+    /* create 3 classifiers */
+    const data_row_id_t test_classifier = test_env_setup_data_create_classifier( "test classifier", &controller );
+    const data_row_id_t omni_classifier = test_env_setup_data_create_classifier( "omni classifier", &controller );
+    const data_row_id_t local_classifier = test_env_setup_data_create_classifier( "local classifier", &controller );
+    
+    /* create 5 diagramelements */
+    const data_row_id_t test_local_diagele 
+        = test_env_setup_data_create_diagramelement( local_diagram, test_classifier, DATA_ROW_ID_VOID, &controller );
+    test_env_setup_data_create_diagramelement( root_diagram, test_classifier, DATA_ROW_ID_VOID, &controller );
+    test_env_setup_data_create_diagramelement( local_diagram, omni_classifier, DATA_ROW_ID_VOID, &controller );
+    test_env_setup_data_create_diagramelement( root_diagram, omni_classifier, DATA_ROW_ID_VOID, &controller );
+    test_env_setup_data_create_diagramelement( local_diagram, local_classifier, DATA_ROW_ID_VOID, &controller );
+
+    /* create 1 feature */
+    const data_row_id_t test_feature = test_env_setup_data_create_feature( test_classifier, "test feature", &controller );
+
+    /* create 2 relationships */
+    const data_row_id_t double_rel 
+        = test_env_setup_data_create_relationship( test_classifier, test_feature,
+                                                   omni_classifier, DATA_ROW_ID_VOID,
+                                                   "double relation", &controller );
+    const data_row_id_t local_rel 
+        = test_env_setup_data_create_relationship( test_classifier, test_feature,
+                                                   local_classifier, DATA_ROW_ID_VOID,
+                                                   "local relation", &controller );
+    
+    /* delete the local diagramelement of the test classifier */
+    const ctrl_error_t c_err 
+        = ctrl_diagram_controller_delete_diagramelement ( diagram_ctrl, test_local_diagele, CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW );
+    TEST_ASSERT_EQUAL_INT( CTRL_ERROR_NONE, c_err );
+    
+    /* is local rel deleted? */
+    data_relationship_t probe;
+    const data_error_t local_err
+        = data_database_reader_get_relationship_by_id( &db_reader, local_rel, &probe );
+    TEST_ASSERT_EQUAL_INT( DATA_ERROR_DB_STRUCTURE, local_err );
+
+    /* is double rel existing? */
+    const data_error_t double_err
+        = data_database_reader_get_relationship_by_id( &db_reader, double_rel, &probe );
+    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, double_err );
+}
+
 
 /*
  * Copyright 2018-2021 Andreas Warnke
