@@ -20,11 +20,10 @@ enum data_feature_type_enum {
     DATA_FEATURE_TYPE_LIFELINE = 3,  /* for sequence, timing, communication and interaction-overview diagrams */
     DATA_FEATURE_TYPE_PROVIDED_INTERFACE = 4,  /* service */
     DATA_FEATURE_TYPE_REQUIRED_INTERFACE = 5,  /* client */
-    /* DATA_FEATURE_TYPE_IN_PORT_PIN = 6, */  /* Rx for component ports, activity pins */
-    /* DATA_FEATURE_TYPE_OUT_PORT_PIN = 7, */  /* Tx for component ports, activity pins */
-    /* DATA_FEATURE_TYPE_ENTRY = 8, */  /* control flow pseudostate for state entry */
-    /* DATA_FEATURE_TYPE_EXIT = 9, */  /* control flow pseudostate for state exit */
-    /* DATA_FEATURE_TYPE_TAG = 10, */  /* for tagged values, distinguish types int, string, ... ? */
+    DATA_FEATURE_TYPE_IN_PORT_PIN = 6,  /* port with SysML-ItemFlow, activity input pin */
+    DATA_FEATURE_TYPE_OUT_PORT_PIN = 7,  /* port with SysML-ItemFlow, activity output pin */
+    DATA_FEATURE_TYPE_ENTRY = 8,  /* control flow pseudostate for state entry */
+    DATA_FEATURE_TYPE_EXIT = 9,  /* control flow pseudostate for state exit */
 };
 
 typedef enum data_feature_type_enum data_feature_type_t;
@@ -33,7 +32,7 @@ typedef enum data_feature_type_enum data_feature_type_t;
 
 
 /*
-Copyright 2016-2020 Andreas Warnke
+Copyright 2016-2021 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
