@@ -193,7 +193,7 @@ static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 =
     "ALTER TABLE diagramelements "
     "ADD COLUMN focused_feature_id INTEGER DEFAULT NULL;";
 
-    data_error_t data_database_private_initialize_tables( data_database_t *this_ )
+data_error_t data_database_private_initialize_tables( data_database_t *this_ )
 {
     TRACE_BEGIN();
 
@@ -208,7 +208,7 @@ static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 =
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_CLASSIFIERINSTANCE_TABLE );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -223,7 +223,7 @@ static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 =
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_RELATIONSHIPINSTANCE_TABLE );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -238,7 +238,7 @@ static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 =
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_FEATUREINSTANCE_TABLE );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -253,7 +253,7 @@ static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 =
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_DIAGRAM_TABLE );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -268,7 +268,7 @@ static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 =
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_DIAGRAMELEMENTS_TABLE );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -297,7 +297,7 @@ data_error_t data_database_private_initialize_indexes( data_database_t *this_ )
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_CLASSIFIERORDERING_INDEX );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -312,7 +312,7 @@ data_error_t data_database_private_initialize_indexes( data_database_t *this_ )
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_RELATIONSHIPORDERING_INDEX );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -327,7 +327,7 @@ data_error_t data_database_private_initialize_indexes( data_database_t *this_ )
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_FEATUREORDERING_INDEX );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -342,7 +342,7 @@ data_error_t data_database_private_initialize_indexes( data_database_t *this_ )
     {
         TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX );
         TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result = DATA_ERROR_AT_DB;
+        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
     }
     if ( error_msg != NULL )
     {
@@ -440,7 +440,7 @@ data_error_t data_database_upgrade_tables( data_database_t *this_ )
         {
             TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_UPDATE_DIAGRAM_ROOT_PARENT );
             TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-            result |= DATA_ERROR_AT_DB;
+            result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
         }
         if ( error_msg != NULL )
         {
@@ -494,7 +494,7 @@ void data_database_init ( data_database_t *this_ )
     TRACE_END();
 }
 
-data_error_t data_database_open ( data_database_t *this_, const char* db_file_path )
+data_error_t data_database_private_open ( data_database_t *this_, const char* db_file_path, int sqlite3_flags )
 {
     TRACE_BEGIN();
     assert( NULL != db_file_path );
@@ -513,12 +513,16 @@ data_error_t data_database_open ( data_database_t *this_, const char* db_file_pa
     {
         utf8stringbuf_copy_str( (*this_).db_file_name, db_file_path );
 
-        TSLOG_EVENT_STR( "sqlite3_open:", utf8stringbuf_get_string( (*this_).db_file_name ) );
-        sqlite_err = sqlite3_open( utf8stringbuf_get_string( (*this_).db_file_name ), &((*this_).db) );
+        TSLOG_EVENT_STR( "sqlite3_open_v2:", utf8stringbuf_get_string( (*this_).db_file_name ) );
+        sqlite_err = sqlite3_open_v2( utf8stringbuf_get_string( (*this_).db_file_name ),
+                                      &((*this_).db),
+                                      sqlite3_flags,
+                                      NULL
+                                    );
         if ( SQLITE_OK != sqlite_err )
         {
-            TSLOG_ERROR_INT( "sqlite3_open() failed:", sqlite_err );
-            TSLOG_ERROR_STR( "sqlite3_open() failed:", utf8stringbuf_get_string( (*this_).db_file_name ) );
+            TSLOG_ERROR_INT( "sqlite3_open_v2() failed:", sqlite_err );
+            TSLOG_ERROR_STR( "sqlite3_open_v2() failed:", utf8stringbuf_get_string( (*this_).db_file_name ) );
             (*this_).is_open = false;
             result |= DATA_ERROR_NO_DB;  /* no db to use */
         }
@@ -822,7 +826,7 @@ data_error_t data_database_private_notify_db_listeners( data_database_t *this_,
 
 
 /*
-Copyright 2016-2020 Andreas Warnke
+Copyright 2016-2021 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
