@@ -15,6 +15,7 @@
 #include "sketch_area/gui_sketch_object_creator.h"
 #include "sketch_area/gui_sketch_overlay.h"
 #include "sketch_area/gui_sketch_background.h"
+#include "sketch_area/gui_sketch_request.h"
 #include "gui_toolbox.h"
 #include "gui_marked_set.h"
 #include "gui_resources.h"
@@ -43,8 +44,6 @@ enum gui_sketch_area_const_enum {
     GUI_SKETCH_AREA_CONST_PARENT_CARD = 1,  /*!< index of the card showing the parent diagram */
     GUI_SKETCH_AREA_CONST_FOCUSED_CARD = 0,  /*!< index of the card showing the currently focused diagram */
     GUI_SKETCH_AREA_CONST_FIRST_CHILD_CARD = 2,  /*!< index of the card showing the first child diagram */
-    GUI_SKETCH_AREA_CONST_FIRST_RESULT_CARD = 1,  /*!< index of the card showing the first search result diagram */
-    GUI_SKETCH_AREA_CONST_MAX_TEMP_DIAGRAMS = 20,  /*!< maximum size of temporary diagram buffer */
 };
 
 /*!
@@ -60,6 +59,9 @@ struct gui_sketch_area_struct {
     gui_marked_set_t *marker;  /*!< pointer to external marker */
     GtkWidget *drawing_area;  /*!< pointer to the gtk drawing area, used as origin for selected-object-changed signals */
 
+    /* the quest */
+    gui_sketch_request_t request;  /*!< own instance of the requested tool-mode and diagram-ids */
+
     /* helper objects */
     gui_sketch_drag_state_t drag_state;  /*!< own instance of the drag state */
     gui_sketch_object_creator_t object_creator;  /*!< own instance of an object creator */
@@ -73,7 +75,6 @@ struct gui_sketch_area_struct {
     gui_sketch_result_list_t result_list;  /*!< own instance of a search result list sub-widget */
 
     /* internal data structures */
-    data_diagram_t private_temp_diagram_buf[GUI_SKETCH_AREA_CONST_MAX_TEMP_DIAGRAMS];
     data_feature_t private_temp_fake_feature;
 };
 
@@ -124,16 +125,14 @@ void gui_sketch_area_show_result_list ( gui_sketch_area_t *this_, const data_sea
  *  \param this_ pointer to own object attributes
  *  \param main_diagram_id id of the main diagram to be shown or DATA_ROW_ID_VOID for root diagram
  */
-void gui_sketch_area_private_load_data ( gui_sketch_area_t *this_, data_row_id_t main_diagram_id );
+void gui_sketch_area_show_diagram ( gui_sketch_area_t *this_, data_id_t main_diagram_id );
 
 /*!
- *  \brief loads the cards and result_list data to be shown in seach mode
+ *  \brief loads the cards and result_list data to be shown in search mode
  *
  *  \param this_ pointer to own object attributes
- *  \param result_list list of search results including their diagram ids to be displayed
- *  \param back_diagram_id id of the previously visible diagram or DATA_ROW_ID_VOID for none
  */
-void gui_sketch_area_private_load_data_list ( gui_sketch_area_t *this_, const data_search_result_list_t *result_list, data_row_id_t back_diagram_id );
+void gui_sketch_area_private_load_cards_data ( gui_sketch_area_t *this_ );
 
 /*!
  *  \brief re-loads the cards, nav_tree and result_list data to be shown
@@ -230,6 +229,8 @@ void gui_sketch_area_private_notify_listeners( gui_sketch_area_t *this_, data_id
 /*!
  *  \brief gets the diagram-id of the diagram at a given position
  *
+ *  This function is intended for use in NAV and SEARCH modes.
+ *
  *  \param this_ pointer to own object attributes
  *  \param x x-position
  *  \param y y-position
@@ -237,6 +238,26 @@ void gui_sketch_area_private_notify_listeners( gui_sketch_area_t *this_, data_id
  */
 static inline data_id_t gui_sketch_area_get_diagram_id_at_pos ( gui_sketch_area_t *this_, int32_t x, int32_t y );
 
+/*!
+ *  \brief gets the diagram-id of the diagram and  the obect-if of the object at a given position
+ *
+ *  Object IDs are only returned for positions in Result-List; 
+ *  objects on cards are ignored because these are to small to cklick on them.
+ *  This function is intended for use in SEARCH mode.
+ * 
+ *  \param this_ pointer to own object attributes
+ *  \param x x-position
+ *  \param y y-position
+ *  \param[out] out_diagram_id a diagram id. The id is invalid if there is no diagram at the given location.
+ *  \param[out] out_object_id an object id. This may refer to a diagram. The id is invalid if there is no diagram at the given location.
+ */
+static inline void gui_sketch_area_get_diagram_and_object_id_at_pos ( gui_sketch_area_t *this_, 
+                                                                      int32_t x, 
+                                                                      int32_t y,
+                                                                      data_id_t* out_diagram_id,
+                                                                      data_id_t* out_object_id 
+                                                                    );
+
 /*!
  *  \brief gets the gui_sketch_card_t at a given position
  *
@@ -249,12 +270,14 @@ static inline gui_sketch_card_t *gui_sketch_area_get_card_at_pos ( gui_sketch_ar
 
 /*!
  *  \brief gets the object-id of the object at a given position
+ * 
+ *  Nav-Tree and Result-List objects are ignored; this function is intended for use in EDIT and CREATE modes.
  *
  *  \param this_ pointer to own object attributes
  *  \param x x-position
  *  \param y y-position
  *  \param filter a filter for object types. E.g. PENCIL_TYPE_FILTER_LIFELINE will return the classifier instead of the lifeline-feature.
- *  \param out_selected_id the object id at the given location. The id is invalid if there is no object at the given location.
+ *  \param[out] out_selected_id the object id at the given location. The id is invalid if there is no object at the given location.
  */
 static inline void gui_sketch_area_private_get_object_id_at_pos ( gui_sketch_area_t *this_,
                                                                   int32_t x,
@@ -266,12 +289,14 @@ static inline void gui_sketch_area_private_get_object_id_at_pos ( gui_sketch_are
 /*!
  *  \brief gets the object-id of the surrounding object and a selected-part-info at a given position
  *
+ *  Nav-Tree and Result-List objects are ignored; this function is intended for use in EDIT and CREATE modes.
+ * 
  *  \param this_ pointer to own object attributes
  *  \param x x-position
  *  \param y y-position
  *  \param filter a filter for object types. E.g. PENCIL_TYPE_FILTER_LIFELINE will return the classifier instead of the lifeline-feature.
- *  \param out_selected_id the object id at the given location. The id is invalid if there is no object at the given location.
- *  \param out_surrounding_id the id of the embracing object at the given location. The id is invalid if there is no object embracing the given location.
+ *  \param[out] out_selected_id the object id at the given location. The id is invalid if there is no object at the given location.
+ *  \param[out] out_surrounding_id the id of the embracing object at the given location. The id is invalid if there is no object embracing the given location.
  */
 static inline void gui_sketch_area_private_get_object_ids_at_pos ( gui_sketch_area_t *this_,
                                                                    int32_t x,
