@@ -66,43 +66,34 @@ void gui_search_request_tool_changed_callback( GtkWidget *widget, gui_tool_t too
     gui_search_request_t *this_ = data;
     assert( NULL != this_ );
 
+    /* info: This function is called once for activating a tool and once for deactiaving it! */
+    
     switch ( tool )
     {
-        case GUI_TOOLBOX_NAVIGATE:
+        case GUI_TOOL_NAVIGATE:
         {
-            TRACE_INFO("GUI_TOOLBOX_NAVIGATE");
+            TRACE_INFO("GUI_TOOL_NAVIGATE");
             gui_search_request_hide( this_ );
         }
         break;
 
-        case GUI_TOOLBOX_EDIT:
+        case GUI_TOOL_EDIT:
         {
-            TRACE_INFO("GUI_TOOLBOX_EDIT");
+            TRACE_INFO("GUI_TOOL_EDIT");
             gui_search_request_hide( this_ );
         }
         break;
 
-        case GUI_TOOLBOX_SEARCH:
+        case GUI_TOOL_SEARCH:
         {
-            TRACE_INFO("GUI_TOOLBOX_SEARCH");
+            TRACE_INFO("GUI_TOOL_SEARCH");
             gui_search_request_show( this_ );
-
-            /* re-trigger the last search - otherwise the screen stays empty */
-            /* would the sketch area store the result list, old search results would be displayed */
-            const char *text = gtk_entry_get_text( GTK_ENTRY( (*this_).search_entry ) );
-            if ( text != NULL )
-            {
-                if ( 0 != utf8string_get_length( text ) )
-                {
-                    gui_search_runner_run ( (*this_).search_runner, text );
-                }
-            }
         }
         break;
 
-        case GUI_TOOLBOX_CREATE:
+        case GUI_TOOL_CREATE:
         {
-            TRACE_INFO("GUI_TOOLBOX_CREATE");
+            TRACE_INFO("GUI_TOOL_CREATE");
             gui_search_request_hide( this_ );
         }
         break;
@@ -142,7 +133,19 @@ void gui_search_request_search_start_callback( GtkWidget* trigger_widget, gpoint
 void gui_search_request_data_changed_callback( GtkWidget *widget, data_change_message_t *msg, gpointer user_data )
 {
     TRACE_BEGIN();
-    TRACE_INFO("callback not yet implemented.");
+    assert( NULL != msg );
+    gui_search_request_t *this_ = user_data;
+    assert( NULL != this_ );
+    assert ( NULL != widget );
+    
+    data_change_event_type_t evt_type;
+    evt_type = data_change_message_get_event ( msg );
+
+    if ( evt_type == DATA_CHANGE_EVENT_TYPE_DB_OPENED )
+    {
+        gtk_entry_set_text ( GTK_ENTRY( (*this_).search_entry ), "" );
+    }
+    
     TRACE_END();
 }
 
