@@ -67,34 +67,25 @@ void gui_sketch_card_layouter_layout ( gui_sketch_card_layouter_t *this_,
     /* layout cards */
     switch( selected_tool )
     {
-        case GUI_TOOLBOX_SEARCH:
+        case GUI_TOOL_SEARCH:
         {
             shape_int_rectangle_t card_bounds;
 
-            /* self: exists - but is not shown */
-            assert(cards_num >= GUI_SKETCH_AREA_CONST_FOCUSED_CARD);
-            {
-                shape_int_rectangle_init( &card_bounds, left+width, top, 0, 0 );
-                gui_sketch_card_set_bounds( &(io_cards[GUI_SKETCH_AREA_CONST_FOCUSED_CARD]), card_bounds );
-                gui_sketch_card_set_visible( &(io_cards[GUI_SKETCH_AREA_CONST_FOCUSED_CARD]), false );
-            }
-
             /* search results */
-            assert(cards_num >= GUI_SKETCH_AREA_CONST_FIRST_RESULT_CARD);
             {
                 shape_int_rectangle_init( &card_bounds, left, top, width, height );
                 gui_sketch_card_layouter_private_layout_to_grid( this_,
                                                                  &card_bounds,
                                                                  focus_card_height,
-                                                                 &(io_cards[GUI_SKETCH_AREA_CONST_FIRST_RESULT_CARD]),
-                                                                 cards_num-GUI_SKETCH_AREA_CONST_FIRST_RESULT_CARD,
+                                                                 io_cards,
+                                                                 cards_num,
                                                                  cr
                                                                );
             }
         }
         break;
 
-        case GUI_TOOLBOX_NAVIGATE:
+        case GUI_TOOL_NAVIGATE:
         {
             shape_int_rectangle_t card_bounds;
 
@@ -141,8 +132,8 @@ void gui_sketch_card_layouter_layout ( gui_sketch_card_layouter_t *this_,
         }
         break;
 
-        case GUI_TOOLBOX_EDIT:  /* or */
-        case GUI_TOOLBOX_CREATE:
+        case GUI_TOOL_EDIT:  /* or */
+        case GUI_TOOL_CREATE:
         {
             shape_int_rectangle_t card_bounds;
 
