@@ -10,6 +10,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF */
     /* note: if a property or association end starts with a slash(/),  */
     /*       it is a derived value and shall not be specified in xmi */
+    /* note: google search pattern for examples may help: filetype:xmi */
 
     /* ================================ CLASSIFIER ================================ */
 
@@ -39,13 +40,11 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         /* spec: https://www.omg.org/spec/SysML/20181001/SysML.xmi (v1.6) pkg: Requirements */
         .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_REQUIREMENT,
         .specification            = XMI_SPEC_SYSML,
-#ifdef NDEBUG
         .profile_name             = "Requirement",
-#else
-        .profile_name             = "x-Requirement", /* the validation tool seems to not allow Requirement */
-#endif
         .base_name                = "Class",
         .is_a                     = (XMI_ELEMENT_IS_A_CLASS),
+        //.base_name                = "NamedElement",
+        //.is_a                     = (XMI_ELEMENT_IS_A_NAMED_ELEMENT),
         .property_from            = NULL,
         .property_to              = NULL,
         .additional_properties    = NULL,
@@ -433,7 +432,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .property_to              = NULL,
         .additional_properties    = NULL,
     },
-    
+
     /* ================================ FEATURE ================================ */
 
     [XMI_ELEMENT_INFO_MAP_INDEX_PROPERTY] = {
@@ -442,7 +441,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "Property",
-        .is_a                     = (XMI_ELEMENT_IS_A_FEATURE|XMI_ELEMENT_IS_A_DEPLOYMENT_TARGET),
+        .is_a                     = (XMI_ELEMENT_IS_A_PROPERTY),
         .property_from            = NULL,
         .property_to              = NULL,
         .additional_properties    = "aggregation=\"composite\"",
@@ -464,14 +463,14 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "Port",
-        .is_a                     = (XMI_ELEMENT_IS_A_FEATURE|XMI_ELEMENT_IS_A_DEPLOYMENT_TARGET),
+        .is_a                     = (XMI_ELEMENT_IS_A_PROPERTY),
         .property_from            = NULL,
         .property_to              = NULL,
         .additional_properties    = "aggregation=\"composite\"",
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_INPUT_PIN] = {
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 16.14.24 */
-        .data_type_checksum       = (int) DATA_FEATURE_TYPE_PORT,
+        .data_type_checksum       = (int) DATA_FEATURE_TYPE_IN_PORT_PIN,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "InputPin",
@@ -482,7 +481,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_OUTPUT_PIN] = {
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 16.14.32 */
-        .data_type_checksum       = (int) DATA_FEATURE_TYPE_PORT,
+        .data_type_checksum       = (int) DATA_FEATURE_TYPE_OUT_PORT_PIN,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "OutputPin",
@@ -491,6 +490,28 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .property_to              = NULL,
         .additional_properties    = NULL,
     },
+    [XMI_ELEMENT_INFO_MAP_INDEX_STATE_ENTRY] = {
+        /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 14.5.6 */
+        .data_type_checksum       = (int) DATA_FEATURE_TYPE_ENTRY,
+        .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
+        .profile_name             = NULL,
+        .base_name                = "Pseudostate",
+        .is_a                     = (XMI_ELEMENT_IS_A_VERTEX),
+        .property_from            = NULL,
+        .property_to              = NULL,
+        .additional_properties    = "kind=\"entryPoint\"",
+    },
+    [XMI_ELEMENT_INFO_MAP_INDEX_STATE_EXIT] = {
+        /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 14.5.6 */
+        .data_type_checksum       = (int) DATA_FEATURE_TYPE_EXIT,
+        .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
+        .profile_name             = NULL,
+        .base_name                = "Pseudostate",
+        .is_a                     = (XMI_ELEMENT_IS_A_VERTEX),
+        .property_from            = NULL,
+        .property_to              = NULL,
+        .additional_properties    = "kind=\"exitPoint\"",
+    },
     [XMI_ELEMENT_INFO_MAP_INDEX_LIFELINE] = {
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 17.12.17 */
         .data_type_checksum       = (int) DATA_FEATURE_TYPE_LIFELINE,
@@ -771,9 +792,35 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     },
 };
 
+const xmi_element_info_t xmi_element_info_map_unknown_type =
+{
+    /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: StructuredClassifiers */
+    .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_CLASS,
+    .specification            = XMI_SPEC_UML,
+    .profile_name             = NULL,
+    .base_name                = "Class",
+    .is_a                     = (XMI_ELEMENT_IS_A_CLASS),
+    .property_from            = NULL,
+    .property_to              = NULL,
+    .additional_properties    = "error=\"unknown type\"",
+};
+
+const xmi_element_info_t xmi_element_info_map_unknown_rel_type =
+{
+    /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 7.8.4 */
+    .data_type_checksum       = (int) DATA_RELATIONSHIP_TYPE_UML_DEPENDENCY,
+    .specification            = (XMI_SPEC_UML),
+    .profile_name             = NULL,
+    .base_name                = "Dependency",
+    .is_a                     = (XMI_ELEMENT_IS_A_DEPENDENCY),
+    .property_from            = "client",
+    .property_to              = "supplier",
+    .additional_properties    = "error=\"unknown type\"",
+};
+
 
 /*
-Copyright 2020-2020 Andreas Warnke
+Copyright 2020-2021 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
