@@ -116,7 +116,7 @@ void xmi_element_writer_init ( xmi_element_writer_t *this_,
     xml_writer_init( &((*this_).xml_writer), output );
     xmi_type_converter_init( &((*this_).xmi_types) );
     xmi_atom_writer_init( &((*this_).atom_writer), db_reader, &((*this_).xml_writer) );
-    
+
     TRACE_END();
 }
 
@@ -179,10 +179,31 @@ int xmi_element_writer_start_classifier( xmi_element_writer_t *this_,
     assert ( NULL != classifier_ptr );
     int export_err = 0;
 
+    const data_id_t classifier_id = data_classifier_get_data_id(classifier_ptr);
+    const data_classifier_type_t classifier_type = data_classifier_get_main_type(classifier_ptr);
+    const xmi_element_info_t *classifier_info;
+    int map_err = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard,
+                                                       parent_type,
+                                                       classifier_type,
+                                                       &classifier_info
+                                                     );
+
     if ( (*this_).mode == IO_WRITER_PASS_BASE )
     {
+        if ( map_err != 0 )
+        {
+            /* The caller requested to write a classifier of unknown type */
+            TRACE_INFO("xmi_element_writer: request to write a classifier of unknown type!")
+            /* update export statistics */
+            data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_CLASSIFIER, DATA_STAT_SERIES_WARNING );
+            /* inform the user via an XML comment: */
+            export_err |= xmi_atom_writer_report_unknown_classifier( &((*this_).atom_writer),
+                                                                     classifier_id,
+                                                                     classifier_type
+                                                                   );
+        }
+        
         /* determine nesting tag */
-        const data_classifier_type_t classifier_type = data_classifier_get_main_type(classifier_ptr);
         const char* nesting_property;
         const int nesting_err
             = xmi_type_converter_get_xmi_nesting_property_of_classifier( &((*this_).xmi_types),
@@ -199,7 +220,6 @@ int xmi_element_writer_start_classifier( xmi_element_writer_t *this_,
             /* update export statistics */
             data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_CLASSIFIER, DATA_STAT_SERIES_WARNING );
             /* inform the user via an XML comment: */
-            const data_id_t classifier_id = data_classifier_get_data_id(classifier_ptr);
             export_err |= xmi_atom_writer_report_illegal_container( &((*this_).atom_writer),
                                                                     classifier_id,
                                                                     classifier_type,
@@ -236,14 +256,21 @@ int xmi_element_writer_assemble_classifier( xmi_element_writer_t *this_,
     const size_t classifier_descr_len = utf8string_get_length(classifier_descr);
     const data_id_t classifier_id = data_classifier_get_data_id(classifier_ptr);
     const data_classifier_type_t classifier_type = data_classifier_get_main_type(classifier_ptr);
-    const xmi_element_info_t *classifier_info
-        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard,
-                                               classifier_type,
-                                               parent_type
-                                             );
+    const xmi_element_info_t *classifier_info;
+    int map_err = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard,
+                                                       parent_type,
+                                                       classifier_type,
+                                                       &classifier_info
+                                                     );
 
     if ( (*this_).mode == IO_WRITER_PASS_BASE )
     {
+        if ( map_err != 0 )
+        {
+            /* The caller requested to write a classifier of unknown type, error was already logged at xmi_element_writer_start_classifier */
+            TRACE_INFO_INT("xmi_element_writer: request to write a classifier of unknown type", classifier_type );
+        }
+        
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_START );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_NS_UML );
         const char* c_type = xmi_type_converter_get_xmi_type_of_classifier ( &((*this_).xmi_types),
@@ -304,7 +331,7 @@ int xmi_element_writer_assemble_classifier( xmi_element_writer_t *this_,
             export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), classifier_name );
 
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "\n" );
-            
+
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
             export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), classifier_descr );
 
@@ -324,6 +351,29 @@ int xmi_element_writer_assemble_classifier( xmi_element_writer_t *this_,
                                                            );
         }
 
+        /* generate extension point for use cases */
+        if ( classifier_type == DATA_CLASSIFIER_TYPE_USE_CASE )
+        {
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_START );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "extensionPoint" );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_START );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_NS_UML );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "ExtensionPoint" );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_END );
+
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_ID_START );
+            export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer),classifier_id );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "#extensionpoint" );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_ID_END );
+            
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_NAME_START );
+            export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), "" );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_NAME_END );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_END );
+        }
+        
         /* generate start of pseudo subelement region to statemachines and states */
         if ( classifier_type == DATA_CLASSIFIER_TYPE_STATE )
         {
@@ -375,6 +425,12 @@ int xmi_element_writer_assemble_classifier( xmi_element_writer_t *this_,
                                                                                     classifier_type,
                                                                                     XMI_SPEC_UML
                                                                                   );
+            if ( classifier_type == DATA_CLASSIFIER_TYPE_REQUIREMENT )
+            {
+                /* the base class is a Class, but the derived property name from AbstractRequirement is base_NamedElement */
+                base_type = "NamedElement";
+                /* but: one could understand differently the SysML 1.6 chapter 16.3.2.5 Requirement */
+            }
             export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), base_type );
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI2_EXT_BASE_ELEMENT_MIDDLE );
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer),classifier_id );
@@ -488,11 +544,28 @@ int xmi_element_writer_start_feature( xmi_element_writer_t *this_,
     const char *const feature_key = data_feature_get_key_ptr( feature_ptr );
     const data_id_t feature_id = data_feature_get_data_id( feature_ptr );
     const data_feature_type_t feature_type = data_feature_get_main_type( feature_ptr );
-    const xmi_element_info_t *feature_info
-        = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, feature_type, XMI_DIRECTION_UNSPECIFIED, parent_type );
+    const xmi_element_info_t *feature_info;
+    int map_err = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, 
+                                                    parent_type,
+                                                    feature_type, 
+                                                    &feature_info
+                                                  );
 
     if ( (*this_).mode == IO_WRITER_PASS_BASE )
     {
+        if ( map_err != 0 )
+        {
+            /* The caller requested to write a feature of unknown type */
+            TRACE_INFO("xmi_element_writer: request to write a feature of unknown type!")
+            /* update export statistics */
+            data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_FEATURE, DATA_STAT_SERIES_WARNING );
+            /* inform the user via an XML comment: */
+            export_err |= xmi_atom_writer_report_unknown_feature( &((*this_).atom_writer),
+                                                                  feature_id,
+                                                                  feature_type
+                                                                );
+        }
+        
         /* determine nesting tag */
         const char* owning_type;
         const int owning_err
@@ -513,6 +586,7 @@ int xmi_element_writer_start_feature( xmi_element_writer_t *this_,
                                                                  feature_type,
                                                                  parent_type
                                                                );
+            owning_type = XMI_ELEMENT_PART_FALLBACK_OWNED_FEATURE;
         }
 
         /* write nesting tag */
@@ -527,7 +601,6 @@ int xmi_element_writer_start_feature( xmi_element_writer_t *this_,
         const char* f_type = xmi_type_converter_get_xmi_type_of_feature ( &((*this_).xmi_types),
                                                                           parent_type,
                                                                           feature_type,
-                                                                          XMI_DIRECTION_UNSPECIFIED,
                                                                           XMI_SPEC_UML
                                                                         );
         export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), f_type );
@@ -629,8 +702,9 @@ int xmi_element_writer_end_feature( xmi_element_writer_t *this_,
         {
             /* The caller requested to write a feature to an illegal place */
             TRACE_INFO("xmi_element_writer: request to write a feature to an illegal place!");
+            owning_type = XMI_ELEMENT_PART_FALLBACK_OWNED_FEATURE;
         }
-        
+
         xml_writer_decrease_indent ( &((*this_).xml_writer) );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_END_TAG_START );
@@ -655,16 +729,30 @@ int xmi_element_writer_start_relationship( xmi_element_writer_t *this_,
     const size_t relation_name_len = utf8string_get_length(relation_name);
     const data_id_t relation_id = data_relationship_get_data_id( relation_ptr );
     const data_relationship_type_t relation_type = data_relationship_get_main_type( relation_ptr );
-    const xmi_element_info_t *relation_info
-        = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard,
-                                                 relation_type,
-                                                 (parent_type==DATA_CLASSIFIER_TYPE_STATE)
-                                               );
-    const bool is_annotated_element 
+    const xmi_element_info_t *relation_info;
+    int map_err = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard,
+                                                         (parent_type==DATA_CLASSIFIER_TYPE_STATE),
+                                                         relation_type,
+                                                         &relation_info
+                                                       );
+    const bool is_annotated_element
         = (( parent_type == DATA_CLASSIFIER_TYPE_COMMENT )&&( relation_type == DATA_RELATIONSHIP_TYPE_UML_DEPENDENCY ));
 
     if ( (*this_).mode == IO_WRITER_PASS_BASE )
     {
+        if ( map_err != 0 )
+        {
+            /* The caller requested to write a relationship of unknown type */
+            TRACE_INFO("xmi_element_writer: request to write a relationship of unknown type!")
+            /* update export statistics */
+            data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_WARNING );
+            /* inform the user via an XML comment: */
+            export_err |= xmi_atom_writer_report_unknown_relationship( &((*this_).atom_writer),
+                                                                       relation_id,
+                                                                       relation_type
+                                                                     );
+        }
+        
         /* determine nesting tag */
         const char* nesting_property;
         const int nesting_err
@@ -698,7 +786,7 @@ int xmi_element_writer_start_relationship( xmi_element_writer_t *this_,
         {
             const data_id_t to_classifier_id = data_relationship_get_to_classifier_data_id( relation_ptr );
             const data_id_t to_feature_id = data_relationship_get_to_feature_data_id( relation_ptr );
-            
+
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_START );
             if ( data_id_is_valid( &to_feature_id ) )
             {
@@ -758,7 +846,7 @@ int xmi_element_writer_start_relationship( xmi_element_writer_t *this_,
                                                              relation_name
                                                            );
         }
-        
+
         /* update export statistics */
         data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_EXPORTED );
     }
@@ -832,24 +920,69 @@ int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
     const data_id_t to_feature_id = data_relationship_get_to_feature_data_id( relation_ptr );
     const data_id_t to_end_id = data_id_is_valid( &to_feature_id ) ? to_feature_id : to_classifier_id;
     const data_relationship_type_t relation_type = data_relationship_get_main_type( relation_ptr );
-    const xmi_element_info_t *relation_info
-        = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard,
-                                                 relation_type,
-                                                 (parent_type==DATA_CLASSIFIER_TYPE_STATE)
-                                               );
+    const xmi_element_info_t *relation_info;
+    int map_err = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard,
+                                                         (parent_type==DATA_CLASSIFIER_TYPE_STATE),
+                                                         relation_type,
+                                                         &relation_info
+                                                       );
+    if ( map_err != 0 )
+    {
+        /* The caller requested to write a relationship of unknown type, error was already logged at xmi_element_writer_start_relationship */
+        TRACE_INFO_INT("xmi_element_writer: request to write a relationship of unknown type", relation_type );
+    }
+        
+    const xmi_element_info_t *from_end_info = NULL;
+    if (from_f_type == DATA_FEATURE_TYPE_VOID)
+    {
+        map_err = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, parent_type /*wrong parent here*/, from_c_type, &from_end_info );
+        if ( map_err != 0 )
+        {
+            TRACE_INFO_INT("xmi_element_writer: request to write a relationship from-end of unknown c-type", from_c_type );
+        }
+    }
+    else
+    {
+        map_err = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, from_c_type, from_f_type, &from_end_info );
+        if ( map_err != 0 )
+        {
+            TRACE_INFO_INT("xmi_element_writer: request to write a relationship from-end of unknown f-type", from_f_type );
+        }
+    }
+    assert ( from_end_info != NULL );
+    
+    const xmi_element_info_t *to_end_info = NULL;
+    if (to_f_type == DATA_FEATURE_TYPE_VOID)
+    {
+        map_err = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, parent_type /*wrong parent here*/, to_c_type, &to_end_info );
+        if ( map_err != 0 )
+        {
+            TRACE_INFO_INT("xmi_element_writer: request to write a relationship to-end of unknown c-type", to_c_type );
+        }
+    }
+    else
+    {
+        map_err = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, to_c_type, to_f_type, &to_end_info );
+        if ( map_err != 0 )
+        {
+            TRACE_INFO_INT("xmi_element_writer: request to write a relationship to-end of unknown f-type", to_f_type );
+        }
+    }
+    assert ( to_end_info != NULL );
+
     /* evaluate if xmi requires to generate fake properties */
     const bool fake_property_ends = xmi_element_info_is_a_association( relation_info );
-    const bool fake_property_at_from_end 
-        = fake_property_ends && (( from_f_type !=  DATA_FEATURE_TYPE_PROPERTY )&&( from_f_type != DATA_FEATURE_TYPE_PORT ));
-    const bool fake_property_at_to_end 
-        = fake_property_ends && (( to_f_type != DATA_FEATURE_TYPE_PROPERTY )&&( to_f_type != DATA_FEATURE_TYPE_PORT ));
+    const bool fake_property_at_from_end
+        = fake_property_ends && ( ! xmi_element_info_is_a_property( from_end_info ) );
+    const bool fake_property_at_to_end
+        = fake_property_ends && ( ! xmi_element_info_is_a_property( to_end_info ) );
     /* check if suppress source end */
-    const bool suppress_source 
-        = (( relation_type == DATA_RELATIONSHIP_TYPE_UML_GENERALIZATION ) 
-        || ( relation_type == DATA_RELATIONSHIP_TYPE_UML_EXTEND ) 
+    const bool suppress_source
+        = (( relation_type == DATA_RELATIONSHIP_TYPE_UML_GENERALIZATION )
+        || ( relation_type == DATA_RELATIONSHIP_TYPE_UML_EXTEND )
         || ( relation_type == DATA_RELATIONSHIP_TYPE_UML_INCLUDE ))
         && parent_is_source;
-    const bool is_annotated_element 
+    const bool is_annotated_element
         = (( parent_type == DATA_CLASSIFIER_TYPE_COMMENT )&&( relation_type == DATA_RELATIONSHIP_TYPE_UML_DEPENDENCY ));
 
     if (( (*this_).mode == IO_WRITER_PASS_BASE )&&( ! is_annotated_element ))
@@ -890,9 +1023,9 @@ int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
                                                                                 true /* = from_end */,
                                                                                 from_c_type,
                                                                                 from_f_type
-                                                                              );                
+                                                                              );
             }
-            
+
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_START );
             export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), from_type_tag );
@@ -911,7 +1044,7 @@ int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_END );
 
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_END );
-            
+
             if ( fake_property_at_from_end )
             {
                 export_err |= xmi_element_writer_private_fake_memberend ( this_,
@@ -950,9 +1083,9 @@ int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
                                                                             false /* = from_end */,
                                                                             to_c_type,
                                                                             to_f_type
-                                                                          );                
+                                                                          );
         }
-            
+
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_START );
         export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), to_type_tag );
@@ -983,8 +1116,20 @@ int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
                                                                       true /* = is_target_end */
                                                                     );
         }
-        
-        /* TODO an Extend relationship needs an Extension point*/
+
+        /* generate extension point for use cases */
+        if ( relation_type == DATA_RELATIONSHIP_TYPE_UML_EXTEND )
+        {
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_START );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "extensionLocation" );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_START );
+            export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_end_id );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "#extensionpoint" );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_END );            
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_END );
+        }
     }
 
     TRACE_END_ERR( export_err );
@@ -1063,26 +1208,31 @@ int xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *this_,
 {
     TRACE_BEGIN();
     int export_err = 0;
-    
-    const bool is_composition 
+
+    const bool is_composition
         = ( relationship_type == DATA_RELATIONSHIP_TYPE_UML_CONTAINMENT )  /* fallback relationship */
         ||( relationship_type == DATA_RELATIONSHIP_TYPE_UML_COMPOSITION );
-    const bool is_aggregation 
+    const bool is_aggregation
         = ( relationship_type == DATA_RELATIONSHIP_TYPE_UML_AGGREGATION );
 
-    const xmi_element_info_t *classifier_info
-        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, 
-                                               end_classifier_type, 
-                                               DATA_CLASSIFIER_TYPE_PACKAGE /* if state or activity context does not matter here */ 
-                                             );
+    const xmi_element_info_t *classifier_info;
+    int map_err = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard,
+                                                       DATA_CLASSIFIER_TYPE_PACKAGE, /* if state or activity context does not matter here */
+                                                       end_classifier_type,
+                                                       &classifier_info
+                                                     );
+    if ( map_err != 0 )
+    {
+        TRACE_INFO_INT("xmi_element_writer: request to write a member end of unknown type", end_classifier_type )
+    }
     assert ( classifier_info != NULL );
-        
+
     /* begin start member-end element */
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_START_TAG_START );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_ELEMENT_OWNED_END );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
-    
+
     /* write type attribute */
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_START );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_NS_UML );
@@ -1110,7 +1260,7 @@ int xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *this_,
     {
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_PROPERTY_AGGREGATION_ATTRIBUTE );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_VALUE_START );
-        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), 
+        export_err |= xml_writer_write_plain ( &((*this_).xml_writer),
                                                is_composition
                                                ? XMI_ELEMENT_PART_PROPERTY_AGGREGATION_COMPOSITE
                                                : XMI_ELEMENT_PART_PROPERTY_AGGREGATION_SHARED
@@ -1118,7 +1268,7 @@ int xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *this_,
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_VALUE_END );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
     }
-    
+
     /* end start member-end element */
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_START_TAG_END );
     xml_writer_increase_indent ( &((*this_).xml_writer) );
@@ -1140,7 +1290,7 @@ int xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *this_,
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_PROPERTY_TYPE_ELEMENT );
     }
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
-    
+
     /* write id-ref attribute */
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_START );
     export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), end_object_id );
@@ -1148,21 +1298,21 @@ int xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *this_,
 
     /* end type element */
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_END );
-    
+
     /* end member-end element */
     xml_writer_decrease_indent ( &((*this_).xml_writer) );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_END_TAG_START );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_ELEMENT_OWNED_END );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_END_TAG_END );
-    
+
     TRACE_END_ERR( export_err );
     return export_err;
 }
 
 
 /*
-Copyright 2020-2020 Andreas Warnke
+Copyright 2020-2021 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
