@@ -10,6 +10,7 @@
 
 /*! where to place the control points of a bezier curve to get a good approximation for a 90 degree curve */
 const static double BEZIER_CTRL_POINT_FOR_90_DEGREE_CIRCLE = 0.552284749831;
+const static double SINE_OF_45_DEGREE = 0.707106781187;
 
 void pencil_feature_painter_init( pencil_feature_painter_t *this_ )
 {
@@ -74,9 +75,18 @@ void pencil_feature_painter_draw ( pencil_feature_painter_t *this_,
 
         switch ( data_feature_get_main_type (the_feature) )
         {
-            case DATA_FEATURE_TYPE_PORT:
+            case DATA_FEATURE_TYPE_PORT:  /* or */
+            case DATA_FEATURE_TYPE_IN_PORT_PIN:  /* or */
+            case DATA_FEATURE_TYPE_OUT_PORT_PIN:
             {
-                pencil_feature_painter_private_draw_port_icon ( this_, layouted_feature, pencil_size, foreground_color, cr );
+                pencil_feature_painter_private_draw_port_pin_icon ( this_, layouted_feature, pencil_size, foreground_color, cr );
+            }
+            break;
+
+            case DATA_FEATURE_TYPE_ENTRY:  /* or */
+            case DATA_FEATURE_TYPE_EXIT:
+            {
+                pencil_feature_painter_private_draw_entry_exit_icon ( this_, layouted_feature, pencil_size, foreground_color, cr );
             }
             break;
 
@@ -217,11 +227,11 @@ void pencil_feature_painter_private_draw_lifeline_icon ( pencil_feature_painter_
     TRACE_END();
 }
 
-void pencil_feature_painter_private_draw_port_icon ( pencil_feature_painter_t *this_,
-                                                     layout_feature_t *layouted_feature,
-                                                     pencil_size_t *pencil_size,
-                                                     GdkRGBA foreground_color,
-                                                     cairo_t *cr )
+void pencil_feature_painter_private_draw_port_pin_icon ( pencil_feature_painter_t *this_,
+                                                         layout_feature_t *layouted_feature,
+                                                         pencil_size_t *pencil_size,
+                                                         GdkRGBA foreground_color,
+                                                         cairo_t *cr )
 {
     TRACE_BEGIN();
     assert( NULL != pencil_size );
@@ -235,15 +245,151 @@ void pencil_feature_painter_private_draw_port_icon ( pencil_feature_painter_t *t
     const double width = geometry_rectangle_get_width ( symbol_box_bounds );
     const double height = geometry_rectangle_get_height ( symbol_box_bounds );
 
-    //double gap = pencil_size_get_standard_object_border( pencil_size );
-
     cairo_rectangle ( cr, left, top, width, height );
 
+    /* Note: It is possible to read out the current color and set it again */
+    /* but the interface for that looks like this might result in 1 additional memory allocation */
+    /* which shall be avoided */
+    /* cairo_pattern_t *const defined_color = cairo_get_source( cr ); */
+    /* cairo_pattern_reference( defined_color );                      */
+    /* ...                                                            */
+    /* cairo_set_source( cr, defined_color );                         */
+    /* cairo_pattern_destroy( defined_color );                        */
+
     cairo_set_source_rgba( cr, 1.0, 1.0, 1.0, 1.0 );  /* white background */
     cairo_fill_preserve (cr);
     cairo_set_source_rgba( cr, foreground_color.red, foreground_color.green, foreground_color.blue, foreground_color.alpha );
     cairo_stroke (cr);
 
+    /* draw the arrow */
+    const double center_x = geometry_rectangle_get_center_x ( symbol_box_bounds );
+    const double center_y = geometry_rectangle_get_center_y ( symbol_box_bounds );
+    const double h_arrow_left = left + 0.25*width;
+    const double h_arrow_right = left + 0.75*width;
+    const double h_arrow_top = top + 0.25*height;
+    const double h_arrow_bottom = top + 0.75*height;
+    const double v_arrow_left = left + 0.25*width;
+    const double v_arrow_right = left + 0.75*width;
+    const double v_arrow_top = top + 0.25*height;
+    const double v_arrow_bottom = top + 0.75*height;
+    switch ( layout_feature_get_icon_direction( layouted_feature ) )
+    {
+        case GEOMETRY_DIRECTION_LEFT:
+        {
+            cairo_move_to ( cr, h_arrow_left, center_y );
+            cairo_line_to ( cr, h_arrow_right, center_y );
+            cairo_move_to ( cr, h_arrow_right, h_arrow_top );
+            cairo_line_to ( cr, h_arrow_left, center_y );
+            cairo_line_to ( cr, h_arrow_right, h_arrow_bottom );
+
+            cairo_stroke (cr);
+        }
+        break;
+
+        case GEOMETRY_DIRECTION_UP:
+        {
+            cairo_move_to ( cr, center_x, v_arrow_top );
+            cairo_line_to ( cr, center_x, v_arrow_bottom );
+            cairo_move_to ( cr, v_arrow_left, v_arrow_bottom );
+            cairo_line_to ( cr, center_x, v_arrow_top );
+            cairo_line_to ( cr, v_arrow_right, v_arrow_bottom );
+
+            cairo_stroke (cr);
+        }
+        break;
+
+        case GEOMETRY_DIRECTION_RIGHT:
+        {
+            cairo_move_to ( cr, h_arrow_right, center_y );
+            cairo_line_to ( cr, h_arrow_left, center_y );
+            cairo_move_to ( cr, h_arrow_left, h_arrow_top );
+            cairo_line_to ( cr, h_arrow_right, center_y );
+            cairo_line_to ( cr, h_arrow_left, h_arrow_bottom );
+
+            cairo_stroke (cr);
+        }
+        break;
+
+        case GEOMETRY_DIRECTION_DOWN:
+        {
+            cairo_move_to ( cr, center_x, v_arrow_bottom );
+            cairo_line_to ( cr, center_x, v_arrow_top );
+            cairo_move_to ( cr, v_arrow_left, v_arrow_top );
+            cairo_line_to ( cr, center_x, v_arrow_bottom );
+            cairo_line_to ( cr, v_arrow_right, v_arrow_top );
+
+            cairo_stroke (cr);
+        }
+        break;
+
+        case GEOMETRY_DIRECTION_CENTER:
+        {
+            /* no arrow */
+        }
+        break;
+
+        default:
+        {
+            TSLOG_ERROR( "unexpected value in geometry_direction_t." );
+        }
+        break;
+    }
+
+    TRACE_END();
+}
+
+void pencil_feature_painter_private_draw_entry_exit_icon ( pencil_feature_painter_t *this_,
+                                                           layout_feature_t *layouted_feature,
+                                                           pencil_size_t *pencil_size,
+                                                           GdkRGBA foreground_color,
+                                                           cairo_t *cr )
+{
+    TRACE_BEGIN();
+    assert( NULL != pencil_size );
+    assert( NULL != layouted_feature );
+    assert( NULL != cr );
+
+    const data_feature_t *the_feature = layout_feature_get_data_const( layouted_feature );
+    const geometry_rectangle_t *const symbol_box_bounds = layout_feature_get_symbol_box_const( layouted_feature );
+
+    const double left = geometry_rectangle_get_left ( symbol_box_bounds );
+    const double top = geometry_rectangle_get_top ( symbol_box_bounds );
+    const double center_x = geometry_rectangle_get_center_x( symbol_box_bounds );
+    const double center_y = geometry_rectangle_get_center_y( symbol_box_bounds );
+    const double circle_x_radius = center_x - left;
+    const double circle_y_radius = center_y - top;
+    const double bottom = geometry_rectangle_get_bottom( symbol_box_bounds );
+    const double right = geometry_rectangle_get_right( symbol_box_bounds );
+    const double ctrl_x_offset = circle_x_radius * (1.0-BEZIER_CTRL_POINT_FOR_90_DEGREE_CIRCLE);
+    const double ctrl_y_offset = circle_y_radius * (1.0-BEZIER_CTRL_POINT_FOR_90_DEGREE_CIRCLE);
+
+    cairo_move_to ( cr, center_x, bottom );
+    cairo_curve_to ( cr, left + ctrl_x_offset, bottom, left, bottom - ctrl_y_offset, left /* end point x */, center_y /* end point y */ );
+    cairo_curve_to ( cr, left, top + ctrl_y_offset, left + ctrl_x_offset, top, center_x /* end point x */, top /* end point y */ );
+    cairo_curve_to ( cr, right - ctrl_x_offset, top, right, top + ctrl_y_offset, right /* end point x */, center_y /* end point y */ );
+    cairo_curve_to ( cr, right, bottom - ctrl_y_offset, right - ctrl_x_offset, bottom, center_x /* end point x */, bottom /* end point y */ );
+
+    cairo_set_source_rgba( cr, 1.0, 1.0, 1.0, 1.0 );  /* white background */
+    cairo_fill_preserve (cr);
+    cairo_set_source_rgba( cr, foreground_color.red, foreground_color.green, foreground_color.blue, foreground_color.alpha );
+    cairo_stroke (cr);
+
+    /* draw X of exit icon */
+    if ( data_feature_get_main_type( the_feature ) == DATA_FEATURE_TYPE_EXIT )
+    {
+        const double half_width = geometry_rectangle_get_width ( symbol_box_bounds )/2.0;
+        const double half_height = geometry_rectangle_get_height ( symbol_box_bounds )/2.0;
+        const double cross_end_dx = half_width * SINE_OF_45_DEGREE;
+        const double cross_end_dy = half_height * SINE_OF_45_DEGREE;
+
+        cairo_move_to ( cr, center_x + cross_end_dx, center_y - cross_end_dy );
+        cairo_line_to ( cr, center_x - cross_end_dx, center_y + cross_end_dy );
+        cairo_move_to ( cr, center_x - cross_end_dx, center_y - cross_end_dy );
+        cairo_line_to ( cr, center_x + cross_end_dx, center_y + cross_end_dy );
+
+        cairo_stroke (cr);
+    }
+
     TRACE_END();
 }
 
@@ -394,7 +540,7 @@ void pencil_feature_painter_get_minimum_bounds ( pencil_feature_painter_t *this_
 
 
 /*
-Copyright 2017-2020 Andreas Warnke
+Copyright 2017-2021 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
