@@ -774,7 +774,11 @@ pencil_error_t pencil_layouter_get_feature_order_at_pos ( const pencil_layouter_
 
                 case DATA_FEATURE_TYPE_PORT:  /* or */
                 case DATA_FEATURE_TYPE_PROVIDED_INTERFACE:  /* or */
-                case DATA_FEATURE_TYPE_REQUIRED_INTERFACE:
+                case DATA_FEATURE_TYPE_REQUIRED_INTERFACE:  /* or */
+                case DATA_FEATURE_TYPE_IN_PORT_PIN:  /* or */
+                case DATA_FEATURE_TYPE_OUT_PORT_PIN:  /* or */
+                case DATA_FEATURE_TYPE_ENTRY:  /* or */
+                case DATA_FEATURE_TYPE_EXIT:
                 {
                     const geometry_rectangle_t *const closest_parent_symbol_box
                         = layout_visible_classifier_get_symbol_box_const ( closest_parent_instance );
@@ -947,7 +951,7 @@ pencil_error_t pencil_layouter_get_relationship_order_at_pos ( const pencil_layo
 
 
 /*
-Copyright 2017-2020 Andreas Warnke
+Copyright 2017-2021 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
