@@ -8,7 +8,7 @@
  *  \brief UNITTEST for universal_array_list
  */
 
-#include <test_suite.h>
+#include "test_suite.h"
 
 test_suite_t universal_array_list_test_get_list(void);
 
@@ -16,7 +16,7 @@ test_suite_t universal_array_list_test_get_list(void);
 
 
 /*
- * Copyright 2020-2020 Andreas Warnke
+ * Copyright 2020-2021 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
