@@ -3,7 +3,7 @@
 #ifndef UTF8STRINGBUF_TEST_H_
 #define UTF8STRINGBUF_TEST_H_
 
-#include <test_suite.h>
+#include "test_suite.h"
 
 test_suite_t utf8stringbuf_test_get_list(void);
 
@@ -11,7 +11,7 @@ test_suite_t utf8stringbuf_test_get_list(void);
 
 
 /*
- * Copyright 2012-2020 Andreas Warnke
+ * Copyright 2012-2021 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
